<?php

/**
* @author    Eric Sizemore <admin@domainportfolio.us>
* @package   Domain Name Portfolio
* @link      www.domainportfolio.us
* @version   1.5.2
* @copyright (C) 2006 - 2009 Eric Sizemore
* @license   http://www.domainportfolio.us/docs/license.html GNU Public License
* @file      ./admin/add_domains.php
*/

define('IN_DNP', true);
define('IN_ADMIN', true);
define('CALENDAR', true);
require_once('../includes/global.php');

// Logged in?
if (!$adm->verify_auth())
{
	redirect('index.php');
}

// ################################################################
$result = '';

// Insert domain
if (!empty($_POST['submit']))
{
	$domain = sanitize($_POST['domain']);
	$description = str_replace("\r\n", "\n", $_POST['description']);
	$description = sanitize($description, false);
	$keywords = strtolower(sanitize($_POST['keywords']));
	$category = intval($_POST['category']);
	$registrar = sanitize($_POST['registrar']);
	$expiry = str_replace('-', '/', sanitize($_POST['expiry']));
	$price = preg_replace('#([^0-9,\.]+)#', '', sanitize($_POST['price']));
	$status = sanitize($_POST['status']);
	$issite = intval($_POST['issite']);
	$hidden = intval($_POST['hidden']);

	// Let's remove http://, https://, or www.
	$domain = str_replace(array('http://', 'https://'), '', $domain);
	$domain = preg_replace('#^www\.#i', '', $domain);

	// If they do not enter anything for price, or status is one of the below, just set to 0.00
	if (empty($price) OR $status == 'Not For Sale' OR $status == 'Make Offer')
	{
		$price = '0.00';
	}

	// Moniker / GoDaddy make domains all CAPS. We don't want them that way.
	if ($domain == strtoupper($domain))
	{
		$domain = strtolower($domain);
	}

	// Stupid I have to check this.
	$_tmp = explode('/', $expiry);
	$_tmp[2] = ($_tmp[2] > 2037) ? 2037 : $_tmp[2];

	$expiry = implode('/', $_tmp);
	unset($_tmp);

	/**
	* Let's create a session value for domain, description, etc.
	* This way, if there's an error, they don't lose what they've entered.
	*/
	$_SESSION['form'] = array(
		'domain'      => $domain,
		'description' => $description,
		'keywords'    => $keywords,
		'registrar'   => $registrar,
		'expiry'      => $expiry,
		'price'       => $price
	);

	if (!preg_match('#^[a-z-0-9-]+\.[a-z]{2,6}#i', $domain))
	{
		$result .= "The domain is invalid - can only contain 'A-Z', '0-9', '-', '.'. IDN's are not supported at this time.";
	}
	else if (is('domain', $db->prepare($domain)))
	{
		$result .= 'The domain is already in the database.';
	}
	else if (empty($domain) OR empty($registrar) OR empty($expiry))
	{
		$result .= 'One of the required fields were left empty (domain, regisrar, or expiry).';
	}
	else if (!is('expdate', $expiry))
	{
		$result .= 'The expiry date seems to be invalid. Please use the format: mm/dd/yyyy';
	}
	else
	{
		$domain = $db->prepare($domain);
		$description = $db->prepare($description);
		$keywords = $db->prepare($keywords);
		$registrar = $db->prepare($registrar);
		$expiry = strtotime($expiry);
		$price = $db->prepare($price);
		$status = $db->prepare($status);
		$category = ($category != -1) ? $category : 0;

		$sql = $db->query("
			INSERT INTO " . TABLE_PREFIX . "domains
				(catid, domain, description, keywords, registrar, expiry, price, status, added, issite, hidden)
			VALUES
				($category, '$domain', '$description', '$keywords', '$registrar', $expiry, '$price', '$status', " . time() . ", $issite, $hidden)
		");

		if ($sql)
		{
			$result .= "Domain '$domain' added.";

			// Reset the array
			$_SESSION['form'] = array(
				'domain'      => '',
				'description' => '',
				'keywords'    => '',
				'registrar'   => '',
				'expiry'      => '',
				'price'       => ''
			);
		}
		else
		{
			$db->raise_error();
		}
	}
	$result = "<div id=\"result\">$result</div>";
}
else
{
	$_SESSION['form'] = array(
		'domain'      => '',
		'description' => '',
		'keywords'    => '',
		'registrar'   => '',
		'expiry'      => '',
		'price'       => ''
	);
}

// ################################################################
// Output page
$pagetitle = 'Add Domains';

include('../templates/admin/add_domains.php');

?>