<?php

/**
* @author    Eric Sizemore <admin@domainportfolio.us>
* @package   Domain Name Portfolio
* @link      www.domainportfolio.us
* @version   1.5.2
* @copyright (C) 2006 - 2009 Eric Sizemore
* @license   http://www.domainportfolio.us/docs/license.html GNU Public License
* @file      ./admin/add_domains_bulk.php
*/

define('IN_DNP', true);
define('IN_ADMIN', true);
require_once('../includes/global.php');

// Logged in?
if (!$adm->verify_auth())
{
	redirect('index.php');
}

// ################################################################
$result = '';

/**
* Depending on the amount of domains entered,
* this could be quite an intensive process..
*/
if (!empty($_POST['submit']))
{
	$domains = trim(str_replace("\r\n", "\n", $_POST['domains']));
	$domains = preg_split("#\n#", $domains, -1, PREG_SPLIT_NO_EMPTY);
	$domains = clean($domains);

	if (count($domains) == 0)
	{
		$result .= 'You didn\'t enter any domains!';
	}
	else
	{
		$num_lines = count($domains);

		for ($i = 0; $i <= $num_lines; $i++)
		{
			$domains[$i] = sanitize($domains[$i]);

			if (trim($domains[$i]) == '')
			{
				continue;
			}

			$parts = explode(',', $domains[$i]);

			if (count($parts) != 6)
			{
				$result .= "You need to specifiy <code>Domain,Category ID,Registrar,Expiry,Price,Status</code> you entered <em>{$domains[$i]}</em>";
				break;
			}
			else
			{
				// Let's remove http://, https://, or www.
				$parts[0] = str_replace(array('http://', 'https://'), '', $parts[0]);
				$parts[0] = preg_replace('#^www\.#i', '', $parts[0]);

				// Moniker / GoDaddy make domains all CAPS. We don't want them that way.
				if ($parts[0] == strtoupper($parts[0]))
				{
					$parts[0] = strtolower($parts[0]);
				}

				// Category ID
				$parts[1] = intval($parts[1]);

				if (!is('category', $parts[1]))
				{
					$parts[1] = 0;
				}

				// Exp.
				$parts[3] = str_replace('-', '/', $parts[3]);

				$_tmp = explode('/', $parts[3]);
				$_tmp[2] = ($_tmp[2] > 2037) ? 2037 : $_tmp[2];

				$parts[3] = implode('/', $_tmp);
				unset($_tmp);

				// Status
				if (empty($parts[5]) OR !in_array($parts[5], array('For Sale', 'Not For Sale', 'Make Offer', 'Sold')))
				{
					$parts[5] = 'For Sale';
				}

				// Price
				$parts[4] = preg_replace('#([^0-9,\.]+)#', '', $parts[4]);

				if (empty($parts[4]) OR $parts[5] == 'Not For Sale' OR $parts[5] == 'Make Offer')
				{
					$parts[4] = '0.00';
				}

				if (!preg_match('#^[a-z-0-9-]+\.[a-z]{2,6}#i', $parts[0]))
				{
					$result .= "$parts[0] is an invalid domain.<br />";
				}
				else if (is('domain', $db->prepare($parts[0])))
				{
					$result .= "$parts[0] is already in the database.<br />";
				}
				else if (!is('expdate', $parts[3]))
				{
					$result .= "$parts[3] for $parts[0] is an invalid expiration date. Please use the format: mm/dd/yyyy<br />";
				}
				else
				{
					$parts[0] = $db->prepare($parts[0]);
					$parts[2] = $db->prepare($parts[2]);
					$parts[3] = strtotime($parts[3]);
					$parts[4] = $db->prepare($parts[4]);
					$parts[5] = $db->prepare($parts[5]);

					// Insert..
					$sql = $db->query("
						INSERT INTO " . TABLE_PREFIX . "domains
							(catid, domain, description, registrar, expiry, price, status, added, issite, hidden)
						VALUES
							($parts[1], '$parts[0]', '', '$parts[2]', '$parts[3]', '$parts[4]', '$parts[5]', " . time() . ", 0, 0)
					");

					if ($sql)
					{
						$result .= "$parts[0] added.<br />\n";
					}
					else
					{
						$db->raise_error();
					}
				}
			}
		}
	}
	unset($domains);

	$result = "<div id=\"result\" style=\"height: 125px; overflow: scroll;\">$result</div>";
}

// ################################################################
// Output page
$pagetitle = 'Add Domains Bulk';

include('../templates/admin/add_domains_bulk.php');

?>