<?php

/**
* @author    Eric Sizemore <admin@domainportfolio.us>
* @package   Domain Name Portfolio
* @link      www.domainportfolio.us
* @version   1.5.2
* @copyright (C) 2006 - 2009 Eric Sizemore
* @license   http://www.domainportfolio.us/docs/license.html GNU Public License
* @file      ./admin/database.php
*/

define('IN_DNP', true);
define('IN_ADMIN', true);
require_once('../includes/global.php');

// Logged in?
if (!$adm->verify_auth())
{
	redirect('index.php');
}

// ################################################################
$result = '';

$default_tables = array(
	TABLE_PREFIX . 'admin',
	TABLE_PREFIX . 'config',
	TABLE_PREFIX . 'domains',
	TABLE_PREFIX . 'categories'
);

// ################################################################
if (!empty($_POST['backup']))
{
	$format = sanitize($_POST['format']);

	switch ($format)
	{
		case 'xls':
			header('Expires: ' . gmdate('D, d M Y H:i:s') . ' GMT');
			header('Cache-Control: must-revalidate, post-check=0, pre-check=0');
			header('Pragma: no-cache');
			header('Content-Type: application/vnd.ms-excel name="dnp_excel_' . gmdate('d-m-Y') . '.xls"');
			header('Content-Disposition: attachment; filename="dnp_excel_' . gmdate('d-m-Y') . '.xls"');

			$exceldata = "Domain\tCategory\tRegistrar\tExpiration\tStatus\tDate Added\t\n";

			$getdomains = $db->query("
				SELECT domains.*, IF(categories.title IS NULL, 'None', categories.title) AS category
				FROM " . TABLE_PREFIX . "domains AS domains
				LEFT JOIN " . TABLE_PREFIX . "categories AS categories ON (categories.catid = domains.catid)
				ORDER BY domains.domainid ASC
			") or $db->raise_error();

			while ($domain = $db->fetch_array($getdomains))
			{
				/// Build excel data
				$domain['expiry'] = date('m/d/Y', $domain['expiry']);
				$domain['added'] = date('m/d/Y', $domain['added']);
				$exceldata .= "\"$domain[domain]\"\t\"$domain[category]\"\t\"$domain[registrar]\"\t";
				$exceldata .= "\"$domain[expiry]\"\t\"$domain[status]\"\t\"$domain[added]\"\n";
			}
			$db->free_result($getdomains);
			echo $exceldata;
			break;
		case 'sql':
		default:
			$backup = new db_backup($db, $default_tables);

			if ($backup->do_backup())
			{
				$result = 'Your database has been successfully backed up to:<br /><code>' . $backup->file . '</code>';
			}
			else
			{
				$result = 'Your database could not be backed up:<br /><code>' . $backup->error . '</code>';
			}
			break;
	}

	if ($format == 'xls')
	{
		exit;
	}
}

// ################################################################
$restoreoptions = array();

foreach (new DirectoryIterator('backups') AS $file)
{
	if (preg_match('#dnp_backup_([0-9]+)\.sql#i', $file->getFilename()))
	{
		array_push($restoreoptions, $file->getFilename());
	}
}

// Restore?
if (!empty($_POST['restore']))
{
	if ($file != -1)
	{
		$file = 'backups/' . sanitize($_POST['file']);

		$restore = new db_restore($db);

		if ($restore->do_restore($file))
		{
			$result = 'Your database has been successfully restored.';
		}
		else
		{
			$result = $restore->error;
		}
	}
	else
	{
		redirect('database.php');
	}
}

// ################################################################
// Optimize?
if (isset($_GET['optimize'], $_GET['table']) AND in_array($_GET['table'], $default_tables))
{
	$_GET['table'] = $db->prepare($_GET['table']);

	$db->query("OPTIMIZE TABLE $_GET[table]");

	redirect('database.php');
}

// ################################################################
// Get tables and their stats
$tablestats = array();

if ($stats = $db->query("SHOW TABLE STATUS FROM " . $db->prepare($config->get('dbname')) . " LIKE '%" . TABLE_PREFIX . "%'"))
{
	$row = 0;

	while ($stat = $db->fetch_array($stats))
	{
		$stat['class'] = ($row & 1);
		$tablestats[] = $stat;

		$row++;
	}
}

// ################################################################
$pagetitle = 'Database';

include('../templates/admin/database.php');

?>