<?php

/**
* @author    Eric Sizemore <admin@domainportfolio.us>
* @package   Domain Name Portfolio
* @link      www.domainportfolio.us
* @version   1.5.2
* @copyright (C) 2006 - 2009 Eric Sizemore
* @license   http://www.domainportfolio.us/docs/license.html GNU Public License
* @file      ./admin/edit.php
*/

define('IN_DNP', true);
define('IN_ADMIN', true);
define('CALENDAR', true);
require_once('../includes/global.php');

// Logged in?
if (!$adm->verify_auth())
{
	redirect('index.php');
}

// ################################################################
$mode = sanitize($_GET['mode']);

switch ($mode)
{
	case 'domain':
		$domainid = intval($_GET['d']);

		if (!is('domain', $domainid))
		{
			redirect('admin.php');
		}

		$domaininfo = get_value('domainedit', $domainid);

		if (count($domaininfo) == 0)
		{
			redirect('admin.php');
		}

		// Start building the page..
		$result = '';

		// Build selects...
		$hide_select = build_select('hidden', $domaininfo['hidden']);
		$status_select = build_select('status', $domaininfo['status']);
		$cat_select = build_select('category', $domaininfo['catid']);
		$issite_select = build_select('issite', $domaininfo['issite']);

		// ################################################################
		// Update the domain
		if (!empty($_POST['submit']))
		{
			$domain = sanitize($_POST['domain']);
			$description = str_replace("\r\n", "\n", $_POST['description']);
			$description = sanitize($description, false);
			$keywords = strtolower(sanitize($_POST['keywords']));
			$category = intval($_POST['category']);
			$registrar = sanitize($_POST['registrar']);
			$expiry = sanitize($_POST['expiry']);
			$price = preg_replace('#\.[0-9]{2}$#', '', sanitize($_POST['price']));
			$price = preg_replace('#([^0-9,\.]+)#', '', $price);
			$status = sanitize($_POST['status']);
			$issite = intval($_POST['issite']);
			$hidden = intval($_POST['hidden']);

			// Remove http://, https://, and www.
			$domain = str_replace(array('http://', 'https://'), '', $domain);
			$domain = preg_replace('#^www\.#i', '', $domain);

			// If they do not enter anything for price, or status is one of the below, just set to 0.00
			if (empty($price) OR $status == 'Not For Sale' OR $status == 'Make Offer')
			{
				$price = '0.00';
			}

			if (empty($domain) OR empty($registrar) OR empty($expiry))
			{
				$result .= 'Required fields left empty. You must provide a valid domain, registrar, and expiration date.';
			}
			else if (!is('expdate', $expiry))
			{
				$result .= 'The expiration date seems to be invalid. Correct format: mm/dd/yyyy. Eg: ' . date('m/d/Y');
			}
			else
			{
				$domain = $db->prepare($domain);
				$description = $db->prepare($description);
				$keywords = $db->prepare($keywords);
				$registrar = $db->prepare($registrar);
				$expiry = strtotime($expiry);
				$price = $db->prepare($price);
				$status = $db->prepare($status);
				$category = ($category != -1) ? $category : 0;

				$sql = $db->query("
					UPDATE " . TABLE_PREFIX . "domains
					SET catid = $category, domain = '$domain', description = '$description', 
					keywords = '$keywords', registrar = '$registrar', expiry = $expiry, price = '$price',
					status = '$status', issite = $issite, hidden = $hidden
					WHERE domainid = $domainid
					LIMIT 1
				");

				if ($sql)
				{
					$result .= "Domain <code>$domaininfo[domain]</code> updated.";
				}
				else
				{
					$db->raise_error();
				}
			}

			$result = "<div id=\"result\">$result &mdash; <a href=\"./admin.php\">Back</a></div>";

			// Give the form fresh values
			$domaininfo = get_value('domainedit', $domainid);
			$hide_select = build_select('hidden', $domaininfo['hidden']);
			$status_select = build_select('status', $domaininfo['status']);
			$cat_select = build_select('category', $domaininfo['catid']);
			$issite_select = build_select('issite', $domaininfo['issite']);
		}
		break;
	case 'category':
		$catid = intval($_GET['cat']);

		if (!is('category', $catid))
		{
			redirect('categories.php');
		}

		$catinfo = get_value('catedit', $catid);

		if (count($catinfo) == 0)
		{
			redirect('categories.php');
		}

		// Start building the page..
		$result = '';

		// ################################################################
		// Update the category
		if (!empty($_POST['submit']))
		{
			$category = sanitize($_POST['category']);
			$description = str_replace("\r\n", "\n", $_POST['description']);
			$description = sanitize($description);
			$keywords = strtolower(sanitize($_POST['keywords']));

			if (empty($category))
			{
				$result .= 'Category title cannot be left blank!';
			}
			else
			{
				$category = $db->prepare($category);
				$description = $db->prepare($description);
				$keywords = $db->prepare($keywords);

				$sql = $db->query("
					UPDATE " . TABLE_PREFIX . "categories
					SET title = '$category', description = '$description', keywords = '$keywords'
					WHERE catid = $catid
					LIMIT 1
				");

				if ($sql)
				{
					$result .= 'Category successfully updated.';
				}
				else
				{
					$db->raise_error();
				}
			}
			$catinfo = get_value('catedit', $catid);

			$result = "<div id=\"result\">$result &mdash; <a href=\"./categories.php\">Back</a></div>";
		}
		break;
	default:
		redirect('admin.php');
		break;
}

// ################################################################
$pagetitle = 'Edit ' . ucfirst($mode);

include('../templates/admin/edit.php');

?>