<?php

/**
* @author    Eric Sizemore <admin@domainportfolio.us>
* @package   Domain Name Portfolio
* @link      www.domainportfolio.us
* @version   1.5.2
* @copyright (C) 2006 - 2009 Eric Sizemore
* @license   http://www.domainportfolio.us/docs/license.html GNU Public License
* @file      ./admin/search.php
*/

define('IN_DNP', true);
define('IN_ADMIN', true);
require_once('../includes/global.php');

// Logged in?
if (!$adm->verify_auth())
{
	redirect('index.php');
}

// ################################################################
$error = '';

// Performing a search?
if (isset($_REQUEST['query']) AND !empty($_REQUEST['query']))
{
	$search = urldecode($_REQUEST['query']);
	$search = preg_replace('#([^a-z0-9\- \.]+)#i', '', sanitize($search));
	$search = (strpos($search, ' ') !== false) ? array_unique(explode(' ', $search)) : $search;

	// If multiple keywords, check to see they meet the min. length requirement
	$tooshort = false;

	if (is_array($search))
	{
		foreach ($search AS $searchpart)
		{
			$searchpart = trim($searchpart);

			if (strlen($searchpart) < 2)
			{
				$tooshort = true;
				break;
			}
		}
	}

	if ((is_string($search) AND strlen($search) < 2) OR (is_array($search) AND $tooshort))
	{
		$error = 'Please enter a search term that is atleast 2 characters in length.<br />If you entered multiple keywords, one of them was too short.';
	}
	else
	{
		// Ordering
		$orderby = is('orderby', sanitize($_GET['sort']));

		// Multiple keywords?
		if (is_array($search))
		{
			$search = array_map('trim', $search);

			$searchsql = '';

			foreach ($search AS $searchpart)
			{
				$searchpart = $db->prepare($searchpart, true);
				$searchsql .= ($searchsql == '' ? 'WHERE' : 'OR') . " domain LIKE '%$searchpart%' ";
			}
		}
		else
		{
			$searchsql = "WHERE domain LIKE '%" . $db->prepare($search, true) . "%'";
		}

		// Pagination
		$page = (isset($_GET['page'])) ? intval($_GET['page']) : 0;

		$numdomains = $db->query("
			SELECT COUNT(domainid) AS count
			FROM " . TABLE_PREFIX . "domains
			$searchsql
		", true) or $db->raise_error();
		$numdomains = $numdomains['count'];

		$pagination = paginate($numdomains, $page, $orderby, NULL, (is_array($search) ? implode(' ', $search) : $search));

		// ################################################################
		// Build the domain table
		$domains = array();

		if ($numdomains > 0)
		{
			$getdomains = $db->query("
				SELECT domains.*, IF(categories.title IS NULL, 'None', categories.title) AS category
				FROM " . TABLE_PREFIX . "domains AS domains
				LEFT JOIN " . TABLE_PREFIX . "categories AS categories ON (categories.catid = domains.catid)
				" . str_replace(' domain LIKE', ' domains.domain LIKE', $searchsql) . "
				ORDER BY " . ($order_by == 'category' ? 'category' : "domains.$orderby") . " ASC
				LIMIT $pagination[limit], " . $config->get('maxperpage') . "
			") or $db->raise_error();

			$row++;

			while ($domain = $db->fetch_array($getdomains))
			{
				$domain['expiry'] = date('m/d/Y', $domain['expiry']);
				$domain['description'] = ($domain['description'] != '') ? $domain['description'] : $domain['domain'];
				$domain['class'] = ($row & 1);
				$domains[] = $domain;
				$row++;
			}
			$db->free_result($getdomains);
		}
	}

	// ################################################################
	$searchquery = ($search != '' ? '&amp;query=' . urlencode((is_array($search) ? implode(' ', $search) : $search)) : '');
}

// ################################################################
// Output Page

$pagetitle = 'Search' . ($searchquery != '' ? ' Results' : '');

include('../templates/admin/search.php');

?>