<?php

/**
* @author    Eric Sizemore <admin@domainportfolio.us>
* @package   Domain Name Portfolio
* @link      www.domainportfolio.us
* @version   1.5.2
* @copyright (C) 2006 - 2009 Eric Sizemore
* @license   http://www.domainportfolio.us/docs/license.html GNU Public License
* @file      ./contact.php
*/

// for javascript in header file
define('IN_CONTACT', true);
define('IN_DNP', true);
require_once('./includes/global.php');

// ################################################################
// Valid ID?
$domainid = (is_string($_GET['d'])) ? sanitize($_GET['d']) : intval($_GET['d']);

if (!is('domain', $domainid))
{
	redirect('index.php');
}

// ################################################################
// Pull the domain and it's status.
$getdomain = get_value('contact', $domainid);

if (count($getdomain) == 0)
{
	redirect('index.php');
}

$domain = clean($getdomain['domain']);
$status = clean($getdomain['status']);

unset($getdomain);

// Has the domain been sold, or is it not for sale?
if ($status == 'Sold' OR $status == 'Not For Sale')
{
	redirect('index.php');
}

$result = '';

// ################################################################
// Process the form and send the email..
require_once('./includes/recaptcha.class.php');
$recaptcha = new recaptcha();
$recaptcha_error = NULL;

if (!empty($_POST['submit']))
{
	$name = sanitize($_POST['sender_name']);
	$email = sanitize($_POST['sender_email']);
	$offer = sanitize(str_replace($config->get('currency'), '', $_POST['sender_offer']));
	$offer = preg_replace('#\.[0-9]{2}$#', '', $offer);
	$offer = preg_replace('#([^0-9,]+)#', '', $offer);
	$message = str_replace("\r\n", "\n", $_POST['sender_message']);
	$message = wordwrap(sanitize($message, false), 75);

	// The new reCAPTCHA
	$recaptcha_challenge = sanitize($_POST['recaptcha_challenge_field']);
	$recaptcha_response = sanitize($_POST['recaptcha_response_field']);

	/**
	* Let's create a session value for name, email, and message.
	* This way, if there's an error, they don't lose what they've entered.
	*/
	$_SESSION['form'] = array(
		'name'    => $name,
		'email'   => $email,
		'offer'   => $offer,
		'message' => $message
	);

	if (empty($name) OR is('injection', $name))
	{
		$result .= 'Your name is required, please go back and enter your name.';
	}
	else if (empty($email))
	{
		$result .= 'Your email is required, please go back and enter your email.';
	}
	else if (empty($message))
	{
		$result .= 'A message is required, please go back and enter a message.';
	}
	else if (!is('email', $email) OR is('injection', $email))
	{
		$result .= 'Email is invalid. Please try again.';
	}
	else if (is('spam', $message))
	{
		$result .= 'Sorry, but your message seemed a bit like spam.';
	}
	else
	{
        $resp = $recaptcha->check_answer(get_ip(), $recaptcha_challenge, $recaptcha_response);

		if (!$resp->is_valid)
		{
			$recaptcha_error = $resp->error;
			$result .= 'reCAPTCHA: Incorrect. Try again.';
		}
		else
		{
			$recaptcha_error = NULL;

			require_once('./includes/emailer.class.php');
			$emailer = new emailer($config->get('contactemail'), $email, "Inquiry about: $domain");
			$emailer->use_template(array(
				'name'    => $name,
				'domain'  => $domain,
				'offer'   => (empty($offer) ? 'n/a' : $offer),
				'email'   => $email,
				'ip'      => get_ip(),
				'message' => $message
			), 'email.tpl');

			if ($emailer->send())
			{
				$result .= "Thank you, $name, your enquiry was sent.";

				// Reset the session array
				$_SESSION['form'] = array(
					'name'    => '',
					'email'   => '',
					'offer'   => '',
					'message' => ''
				);
			}
			else
			{
				$result .= 'Seems to have been a problem sending the email. Please try again.';
			}
		}
	}
}
else
{
	$_SESSION['form'] = array(
		'name'    => '',
		'email'   => '',
		'offer'   => '',
		'message' => ''
	);
}

// ################################################################
// Output page
$pagetitle = "Inquiring about $domain";

include("$template/contact.php");

?>