<?php

/**
* @author    Eric Sizemore <admin@domainportfolio.us>
* @package   Domain Name Portfolio
* @link      www.domainportfolio.us
* @version   1.5.2
* @copyright (C) 2006 - 2009 Eric Sizemore
* @license   http://www.domainportfolio.us/docs/license.html GNU Public License
* @file      ./includes/admin.class.php
*/

if (!defined('IN_DNP'))
{
	die('You\'re not supposed to be here.');
}

class admin
{
	/**
	* This will hold all the needed admin data.
	*
	* private, cannot be accessed directly outside of this class.
	*
	* @var array
	*/
	private $admininfo;

	/**
	* Constructor.
	*
	* Basically just sets up the admininfo array.
	*
	* @param  void
	* @return void
	*/
	public function __construct()
	{
		$this->admininfo = array();
	}

	/**
	* This will generate a hash composed of useragent, ipaddress, and ID.
	* We can use this to verify an admin's login, and keep it rather secure.
	*
	* private, cannot be accessed directly outside of this class.
	*
	* @param  integer  Admin ID
	* @return string   Generated hash
	*/
	private function gen_hash($adminid)
	{
		$hash = "DomainNamePortfolio:admin_id=$adminid;ip_seg=";
		$hash .= implode('.', array_slice(explode('.', get_ip()), 0, 2)) . ';';
		$hash .= 'useragent=' . dnp_getenv('HTTP_USER_AGENT') . ';';
		return dnp_hash($hash);
	}

	/**
	* Handles the admin login.
	*
	* @param  string   Admin username
	* @param  string   dnp_hash'ed admin password
	* @return boolean  True if able to login, false if not.
	*/
	public function do_login($username, $password, $fromglobal = false)
	{
		global $db;

		$getadmininfo = $db->query("
			SELECT adminid, username, password
			FROM " . TABLE_PREFIX . "admin
			WHERE username='" . $db->prepare($username) . "'
		") or $db->raise_error('admin->do_login - Failed getting admin information.');

		if ($admininfo = $db->fetch_array($getadmininfo))
		{
			if ($username == $admininfo['username'] AND $password == ($fromglobal ? dnp_hash($admininfo['password']) : $admininfo['password']))
			{
				// userinfo array
				$this->admininfo['dnp_admin_id'] = $admininfo['adminid'];
				$this->admininfo['dnp_admin_name'] = $admininfo['username'];
				$this->admininfo['dnp_admin_key'] = substr(dnp_hash($admininfo['password']), 0, 16);
				$this->admininfo['dnp_admin_hash'] = $this->gen_hash($admininfo['adminid']);

				// sessions
				$_SESSION['dnp_admin_id'] = $this->admininfo['dnp_admin_id'];
				$_SESSION['dnp_admin_name'] = $this->admininfo['dnp_admin_name'];
				$_SESSION['dnp_admin_key'] = $this->admininfo['dnp_admin_key'];
				$_SESSION['dnp_admin_kp'] = dnp_hash($admininfo['password']);
				$_SESSION['dnp_admin_hash'] = $this->admininfo['dnp_admin_hash'];
				return true;
			}
		}
		return false;
	}

	/**
	* Checks if admin is logged in on each admin page load.
	*
	* @param  void
	* @return boolean True if logged in, false if not.
	*/
	public function verify_auth()
	{
		global $db;

		$adminid = intval($_SESSION['dnp_admin_id']);
		$username = sanitize($_SESSION['dnp_admin_name']);
		$passkey = sanitize($_SESSION['dnp_admin_key']);
		$hash = sanitize($_SESSION['dnp_admin_hash']);

		if (empty($adminid) OR empty($username) OR empty($passkey) OR empty($hash))
		{
			return false;
		}

		if ($hash != $this->gen_hash($adminid))
		{
			$this->do_logout();
			return false;
		}

		if (
			$adminid == $this->admininfo['dnp_admin_id'] AND 
			$username == $this->admininfo['dnp_admin_name'] AND 
			$passkey == $this->admininfo['dnp_admin_key'] AND 
			$hash == $this->admininfo['dnp_admin_hash']
		)
		{
			return true;
		}
		return false;
	}

	/**
	* Will allow an admin to logout of the system.
	*
	* @param  void
	* @return void
	*/
	public function do_logout()
	{
		$this->admininfo = array();

		unset(
			$_SESSION['dnp_admin_id'],
			$_SESSION['dnp_admin_name'],
			$_SESSION['dnp_admin_key'],
			$_SESSION['dnp_admin_kp'],
			$_SESSION['dnp_admin_hash']
		);

		if (isset($_COOKIE[session_name()]))
		{
			$expire = intval(ini_get('session.cookie_lifetime'));
			$expire = ($expire == 0) ? 1200 : $expire;
			setcookie(session_name(), '', time() - $expire, '/');
		}
		session_destroy();
	}
}

?>