<?php

/**
* @author    Eric Sizemore <admin@domainportfolio.us>
* @package   Domain Name Portfolio
* @link      www.domainportfolio.us
* @version   1.5.2
* @copyright (C) 2006 - 2009 Eric Sizemore
* @license   http://www.domainportfolio.us/docs/license.html GNU Public License
* @file      ./includes/config.php
*/

/**
* This class will handle all of our configuration options.
*/
class dnp_config
{
	/**
	* This will hold our config info.
	*
	* private, cannot be accessed directly outside of this class.
	*
	* @var array
	*/
	private $info = array();

	/**
	* Constructor. Initiates the info array with default configuration options.
	*
	* The configuration options within this function have to be set before installation.
	*
	* @param  void
	* @return void
	*/
	public function __construct()
	{
		$this->info = array(
			/**
			* This is the hostname or IP address of your database server.
			*/
			'dbhost'    => 'localhost',

			/**
			* This is the username and password to conntect to the database server.
			*/
			'dbuser'    => 'username',
			'dbpass'    => 'password',

			/**
			* This is the name of the database you created.
			*/
			'dbname'    => 'database',

			/**
			* This determines which PHP extension we'll use, either mysql or mysqli
			* To use MySQLi PHP must be compiled with: --with-mysqli=/path/to/mysql_config
			*/
			'dbtype'    => (function_exists('mysqli_init') ? 'mysqli' : 'mysql'),

			/**
			* This is the prefix added to database tables, shouldn't need changed.
			*/
			'dbprefix'  => 'dnp_',

			/**
			* This is the email address used when there is a database error.
			*/
			'dbemail'   => 'webmaster@example.com',

			/**
			* This determines which reCAPTCHA theme we use. reCAPTCHA is used on the contact page.
			* Valid options are: red, white, blackglass, or clean
			*/
			'recaptcha' => 'red',

			/**
			* This determines which template to use for the main site.
			* Valid options are: default or legacy
			*/
			'template'  => 'default'
		);
	}

	/**
	* Returns the value of a configuration option for use within the script.
	* It can also return all configuration items from the database.
	*
	* @param  mixed    Name of the option to lookup
	* @param  boolean  If we're wanting to pull configuration options from the database.
	* @return string   Value of the given option, if any.
	*/
	public function get($option, $fromdb = false)
	{
		global $db;

		if ($fromdb AND !defined('IN_INSTALL') AND is_object($db))
		{
			// Get site config info
			$getconfig = $db->query("
				SELECT name, value
				FROM " . TABLE_PREFIX . "config
			") or $db->raise_error();

			while ($configrow = $db->fetch_array($getconfig))
			{
				$this->info["$configrow[name]"] = clean($configrow['value']);
			}
			$db->free_result($getconfig);
		}
		else
		{
			return (isset($this->info["$option"])) ? $this->info["$option"] : '';
		}
	}

	/**
	* Updates a config option in the database.
	*
	* @param  string   Config option to update
	* @param  mixed    Config value
	* @return boolean  true if update is successful, or false if not.
	*/
	public function update($option, $value)
	{
		global $db;

		$valid_options = array(
			'title',
			'description',
			'keywords',
			'maxperpage',
			'contactemail',
			'currency',
		);

		if (empty($option) OR !in_array($option, $valid_options))
		{
			die('config::update(): $option must be a valid configuration option.');
		}

		if ($db->query("UPDATE " . TABLE_PREFIX . "config SET value = '$value' WHERE name = '$option'"))
		{
			return true;
		}
		else
		{
			$db->raise_error();
		}
		return false;
	}
}

?>