<?php

/**
* @author    Eric Sizemore <admin@domainportfolio.us>
* @package   Domain Name Portfolio
* @link      www.domainportfolio.us
* @version   1.5.2
* @copyright (C) 2006 - 2009 Eric Sizemore
* @license   http://www.domainportfolio.us/docs/license.html GNU Public License
* @file      ./includes/database.class.php
*/

if (!defined('IN_DNP'))
{
	die('You\'re not supposed to be here.');
}

/**
* Class to interact with a mysql database.
*/
class db_mysql
{
	/**
	* Connection to MySQL.
	*
	* protected, cannot be accessed directly outside of this class or child classes.
	*
	* @var string
	*/
	protected $link;

	/**
	* Holds the most recent connection.
	*
	* protected, cannot be accessed directly outside of this class or child classes.
	*
	* @var string
	*/
	protected $recent_link = NULL;

	/**
	* Holds the contents of the most recent SQL query.
	*
	* protected, cannot be accessed directly outside of this class or child classes.
	*
	* @var string
	*/
	protected $sql = '';

	/**
	* The text of the most recent database error message.
	*
	* protected, cannot be accessed directly outside of this class or child classes.
	*
	* @var string
	*/
	protected $error = '';

	/**
	* The error number of the most recent database error message.
	*
	* @var integer
	*/
	public $errno = '';

	/**
	* We set this outside of the class. If set to true, the error message/sql is displayed.
	*
	* @var boolean
	*/
	public $is_admin = false;

	/**
	* Constructor. Initializes a database connection and selects our database.
	*
	* @param  string   Database host
	* @param  string   Database username
	* @param  string   Database password
	* @param  string   Database name
	* @return boolean  Connection resource, if database connection is established.
	*/
	public function __construct($db_host, $db_user, $db_pass, $db_name)
	{
		$this->link = @mysql_connect($db_host, $db_user, $db_pass);

		if ($this->link)
		{
			if (@mysql_select_db($db_name, $this->link))
			{
				$this->recent_link =& $this->link;
				return $this->link;
			}
		}

		// If we couldn't connect or select the db...
		$this->raise_error("db_mysql::__construct() - Could not select and/or connect to database: $db_name");
	}

	/**
	* Executes a sql query. If optional $only_first is set to true, it will
	* return the first row of the result as an array.
	*
	* @param  string   Query to run
	* @param  boolean  Return only the first row, as an array?
	* @return mixed    Result resource, or first row array if $only_first is true
	*/
	public function query($sql, $only_first = false)
	{
		$this->recent_link =& $this->link;
		$this->sql =& $sql;
		$result = @mysql_query($sql, $this->link);

		if ($only_first)
		{
			$return = $this->fetch_array($result);
			$this->free_result($result);
			return $return;
		}
		return $result;
	}

	/**
	* Fetches a row from a query result and returns the values from that row as an array.
	*
	* @param  string  The query result we are dealing with.
	* @return array   Fetched row as array.
	*/
	public function fetch_array($result)
	{
		return @mysql_fetch_assoc($result);
	}

	/**
	* Returns the number of rows in a result set.
	*
	* @param  string   The query result we are dealing with.
	* @return integer  Number of rows.
	*/
	public function num_rows($result)
	{
		return @mysql_num_rows($result);
	}

	/**
	* Escapes a value to make it safe for using in queries.
	*
	* @param  string   Value to be escaped
	* @param  boolean  Do we need to escape this string for a LIKE statement?
	* @return string   Escaped value.
	*/
	public function prepare($value, $do_like = false)
	{
		$value = stripslashes($value);

		if ($do_like)
		{
			$value = str_replace(array('%', '_'), array('\%', '\_'), $value);
		}
		return @mysql_real_escape_string($value, $this->link);
	}

	/**
	* Frees memory associated with a query result.
	*
	* @param  string  The query result we are dealing with.
	* @return void
	*/
	public function free_result($result)
	{
		return @mysql_free_result($result);
	}

	/**
	* Closes our connection to MySQL.
	*
	* @param  void
	* @return void
	*/
	public function close()
	{
		$this->sql = '';
		return @mysql_close($this->link);
	}

	/**
	* Returns the MySQL error message.
	*
	* @param  void
	* @return string  Error message.
	*/
	public function error()
	{
		$this->error = (is_null($this->recent_link)) ? '' : @mysql_error($this->recent_link);
		return $this->error;
	}

	/**
	* Returns the MySQL error number.
	*
	* @param  void
	* @return integer  Error number.
	*/
	public function errno()
	{
		$this->errno = (is_null($this->recent_link)) ? 0 : @mysql_errno($this->recent_link);
		return $this->errno;
	}

	/**
	* Gets the url/path of where we are when a MySQL error occurs.
	*
	* final protected, cannot be accessed directly outside of this class or child classes;
	* cannot be modified by child classes.
	*
	* @param  void
	* @return string  URL/path to the file which had the error.
	*/
	final protected function get_error_path()
	{
		if (dnp_getenv('REQUEST_URI'))
		{
			$errorpath = dnp_getenv('REQUEST_URI');
		}
		else
		{
			if (dnp_getenv('PATH_INFO'))
			{
				$errorpath = dnp_getenv('PATH_INFO');
			}
			else
			{
				$errorpath = dnp_getenv('PHP_SELF');
			}

			if (dnp_getenv('QUERY_STRING'))
			{
				$errorpath .= '?' . dnp_getenv('QUERY_STRING');
			}
		}

		if (($pos = strpos($errorpath, '?')) !== false)
		{
			$errorpath = urldecode(substr($errorpath, 0, $pos)) . substr($errorpath, $pos);
		}
		else
		{
			$errorpath = urldecode($errorpath);
		}
		return 'http://' . dnp_getenv('SERVER_NAME') . sanitize($errorpath);
	}

	/**
	* If there is a database error, the script will be stopped and an error message displayed.
	*
	* final, cannot be modified by child classes.
	*
	* @param  string  The error message. If empty, one will be built with $this->sql.
	* @return void
	*/
	final public function raise_error($errormsg = '')
	{
		global $config;

		if ($this->recent_link)
		{
			$this->error = $this->error($this->recent_link);
			$this->errno = $this->errno($this->recent_link);
		}

		if ($errormsg == '')
		{
			$this->sql = "Error in SQL query:\n\n" . rtrim($this->sql) . ';';
			$errormsg =& $this->sql;
		}
		else
		{
			$errormsg = $errormsg . ($this->sql != '' ? "\n\nSQL:" . rtrim($this->sql) . ';' : '');
		}

		$message = htmlspecialchars("$errormsg\n\nError: {$this->error}\nError Number: {$this->errno}\nFilename: " . $this->get_error_path());
		$message = '<code>' . nl2br($message) . '</code>';

		if (!$this->is_admin)
		{
			$message = "<!--\n\n$message\n\n-->";
		}

		// Set the correct path to the error template
		$path = (defined('IN_ADMIN') OR defined('IN_INSTALL')) ? '..' : '.';

		$title = ($config->get('title') == '') ? 'Domain Name Portfolio' : $config->get('title');
		$dbemail = encode_email($config->get('dbemail'));

		eval('$output = "' . addslashes(file_get_contents("$path/templates/dberror.tpl")) . '";');
		die($output);
	}
}

/**
* Class to interact with a mysql database, using MySQL Improved.
*/
class db_mysqli extends db_mysql
{
	/**
	* Constructor. Initializes a database connection and selects our database.
	*
	* @param  string    Database host
	* @param  string    Database username
	* @param  string    Database password
	* @param  string    Database name
	* @param  string    Config file (my.ini / my.cnf)
	* @return resource  Connection resource, if database connection is established.
	*/
	public function __construct($db_host, $db_user, $db_pass, $db_name, $configfile = '')
	{
		$this->link = @mysqli_init();

		if (!empty($configfile))
		{
			@mysqli_options($this->link, MYSQLI_READ_DEFAULT_FILE, $configfile);
		}

		$connect = @mysqli_real_connect($this->link, $db_host, $db_user, $db_pass, $db_name);

		if ($connect)
		{
			if (@mysqli_select_db($this->link, $db_name))
			{
				$this->recent_link =& $this->link;
				return $this->link;
			}
		}

		// If we couldn't connect or select the db...
		$this->raise_error("db_mysqli->db_mysqli - Could not select and/or connect to database: $db_name");
	}

	/**
	* Executes a sql query. If optional $only_first is set to true, it will
	* return the first row of the result as an array.
	*
	* @param  string   Query to run
	* @param  boolean  Return only the first row, as an array?
	* @return mixed    Result resource, or first row array if $only_first is true
	*/
	public function query($sql, $only_first = false)
	{
		$this->recent_link =& $this->link;
		$this->sql =& $sql;
		$result = @mysqli_query($this->link, $sql);

		if ($only_first)
		{
			$return = $this->fetch_array($result);
			$this->free_result($result);
			return $return;
		}
		return $result;
	}

	/**
	* Fetches a row from a query result and returns the values from that row as an array.
	*
	* @param  string  The query result we are dealing with.
	* @return array   Fetched row as array.
	*/
	public function fetch_array($result)
	{
		return @mysqli_fetch_assoc($result);
	}

	/**
	* Returns the number of rows in a result set.
	*
	* @param  string   The query result we are dealing with.
	* @return integer  Number of rows.
	*/
	public function num_rows($result)
	{
		return @mysqli_num_rows($result);
	}

	/**
	* Escapes a value to make it safe for using in queries.
	*
	* @param  string   Value to be escaped
	* @param  boolean  Do we need to escape this string for a LIKE statement?
	* @return string   Escaped value.
	*/
	public function prepare($value, $do_like = false)
	{
		$value = stripslashes($value);

		if ($do_like)
		{
			$value = str_replace(array('%', '_'), array('\%', '\_'), $value);
		}
		return @mysqli_real_escape_string($this->link, $value);
	}

	/**
	* Frees memory associated with a query result.
	*
	* @param  string  The query result we are dealing with.
	* @return void
	*/
	public function free_result($result)
	{
		return @mysqli_free_result($result);
	}

	/**
	* Closes our connection to MySQLi.
	*
	* @param  void
	* @return void
	*/
	public function close()
	{
		$this->sql = '';
		return @mysqli_close($this->link);
	}

	/**
	* Returns the MySQLi error message.
	*
	* @param  void
	* @return string  Error message.
	*/
	public function error()
	{
		$this->error = (is_null($this->recent_link)) ? '' : @mysqli_error($this->recent_link);
		return $this->error;
	}

	/**
	* Returns the MySQLi error number.
	*
	* @param  void
	* @return integer  Error number.
	*/
	public function errno()
	{
		$this->errno = (is_null($this->recent_link)) ? 0 : @mysqli_errno($this->recent_link);
		return $this->errno;
	}
}

/**
* Class to backup the database.
*/
class db_backup
{
	/**
	* An array of tables to backup
	*
	* protected, cannot be accessed directly outside of this class;
	* cannot be modified by child classes.
	*
	* @var array
	*/
	protected $tables;

	/**
	* Database (db_mysql/db_mysqli) object
	*
	* protected, cannot be accessed directly outside of this class;
	* cannot be modified by child classes.
	*
	* @var object
	*/
	protected $dbobj;

	/**
	* Path to the backup file.
	*
	* @var string
	*/
	public $file;

	/**
	* Contains the error message, if an error occurs.
	*
	* @var string
	*/
	public $error;

	/**
	* Constructor. Sets db_mysql/db_mysqli object and $table array
	*
	* @param  object  Database (db_mysql/db_mysqli) object
	* @param  array   Array of database tables to backup
	* @return void
	*/
	public function __construct(&$db, $tables)
	{
		if (!is_array($tables))
		{
			die('db_backup::__construct() $tables must be an array');
		}

		$this->tables = $tables;
		$this->dbobj =& $db;
	}

	/**
	* Gets the table structure.
	*
	* CREATE TABLE ...
	*
	* protected, cannot be accessed directly outside of this class;
	* cannot be modified by child classes.
	*
	* @param  string  Table to get structure for.
	* @return string  Table structure.
	*/
	protected function get_tbl_structure($table)
	{
		$struct = "\n--\n-- Table stucture for table `$table`\n--\n";
		$struct .= "DROP TABLE IF EXISTS `$table`;\n";
		$struct .= "CREATE TABLE `$table` (\n";

		// Fields
		$fields = $this->get_fields($table);

		foreach ($fields AS $key => $value)
		{
			$struct .= "\t`$value[Field]` $value[Type]";
			$struct .= ($value['Null'] != 'YES') ? ' NOT NULL' : '';
			$struct .= ($value['Default'] != '') ? " DEFAULT '$value[Default]'" : '';
			$struct .= ($value['Extra'] != '') ? " $value[Extra]" : '';
			$struct .= ",\n";
		}
		$struct = rtrim($struct, ",\n");

		// Keys
		$keys = $this->get_keys($table);

		foreach ($keys AS $key => $value)
		{
			$kname = $value['Key_name'];

			if (($kname != 'PRIMARY') AND ($value['Non_unique'] == 0))
			{
				$kname = "UNIQUE|$kname";
			}

			if (!isset($index[$kname]))
			{
				$index[$kname] = array();
			}
			$index[$kname][] = "`$value[Column_name]`";
		}

		while (list($x, $columns) = @each($index))
		{
			$struct .= ",\n";

			if ($x == 'PRIMARY')
			{
				$struct .= "\tPRIMARY KEY (" . implode($columns, ', ') . ')';
			}
			else if (substr($x, 0, 6) == 'UNIQUE')
			{
				$struct .= "\tUNIQUE `" . substr($x, 7) . '` (' . implode($columns, ', ') . ')';
			}
			else
			{
				$struct .= "\tKEY `$x` (" . implode($columns, ', ') . ')';
			}
		}

		$struct .= "\n);";

		return clean($struct);
	}

	/**
	* Gets the table data/content.
	*
	* INSERT INTO ... VALUES(...)
	*
	* protected, cannot be accessed directly outside of this class;
	* cannot be modified by child classes.
	*
	* @param  string  Table to get data/content for.
	* @return string  Table data/content.
	*/
	protected function get_tbl_content($table)
	{
		$data = $this->get_data($table);
		$content = "\n--\n-- Dumping data for table `$table`\n--\n";

		foreach ($data AS $key => $value)
		{
			$content .= "INSERT INTO `$table` VALUES (";

			foreach ($value AS $key2 => $value2)
			{
				if (!isset($value[$key2]))
				{
					$content .= 'NULL, ';
				}
				else if ($value[$key2] != '')
				{
					$content .= "'" . $this->dbobj->prepare($value[$key2]) . "', ";
				}
				else
				{
					$content .= "'', ";
				}
			}
			$content = rtrim($content, ', ');
			$content .= ");\n";
		}
		return $content;
	}

	/**
	* Helper function for get_table_content
	*
	* protected, cannot be accessed directly outside of this class;
	* cannot be modified by child classes.
	*
	* @param  string  Table to get data/content for.
	* @return string  Tabel content.
	*/
	protected function get_data($table)
	{
		$ret = array();
		$res = $this->dbobj->query("SELECT * FROM $table");

		while ($temp = $this->dbobj->fetch_array($res))
		{
			array_push($ret, $temp);
		}
		$this->dbobj->free_result($res);

		return $ret;
	}

	/**
	* Helper function for get_table_structure
	*
	* Gets table keys.
	*
	* protected, cannot be accessed directly outside of this class;
	* cannot be modified by child classes.
	*
	* @param  string  Table to get keys for.
	* @return string  Table keys.
	*/
	protected function get_keys($table)
	{
		$ret = array();
		$res = $this->dbobj->query("SHOW KEYS FROM $table");

		while ($temp = $this->dbobj->fetch_array($res))
		{
			array_push($ret, $temp);
		}
		$this->dbobj->free_result($res);

		return $ret;
	}

	/**
	* Helper function for _get_table_structure
	*
	* Gets table fields.
	*
	* protected, cannot be accessed directly outside of this class;
	* cannot be modified by child classes.
	*
	* @param  string  Table to get fields for.
	* @return string  Table fields.
	*/
	protected function get_fields($table)
	{
		$ret = array();
		$res = $this->dbobj->query("SHOW FIELDS FROM $table");

		while ($temp = $this->dbobj->fetch_array($res))
		{
			array_push($ret, $temp);
		}
		$this->dbobj->free_result($res);

		return $ret;
	}

	/**
	* Performs the actual backup
	*
	* @param  void
	* @return integer  Number > 0 if successful, 0 otherwise. 
	*/
	public function do_backup()
	{
		global $version;

		if (!is_writable('backups'))
		{
			$this->error = './admin/backups not writable';
			return false;
		}

		$this->file = "backups/dnp_backup_" . time() . ".sql";

		$backup = "--\n-- Domain Name Portfolio Backup\n";
		$backup .= "-- DNP Version: $version\n";
		$backup .= "--\n-- DATE : " .  gmdate('D, d M Y H:i:s') . " GMT\n";
		$backup .= "--\n-- -------------------------------------------\n\n";

		foreach ($this->tables AS $table)
		{
			$backup .= $this->get_tbl_structure($table) . "\n\n" . $this->get_tbl_content($table) . "\n\n";
		}

		@touch($this->file);

		return (file_put_contents($this->file, $backup));
	}
}

/**
* Class to restore a database backup.
*/
class db_restore
{
	/**
	* If an error occurs, this will tell us what it is.
	*
	* @var string
	*/
	public $error;

	/**
	* Database (db_mysql/db_mysqli) object
	*
	* protected, cannot be accessed directly outside of this class;
	* cannot be modified by child classes.
	*
	* @var object
	*/
	protected $dbobj;

	/**
	* Constructor. Sets db_mysql/db_mysqli object
	*
	* @param  object  Database (db_mysql/db_mysqli) object
	* @return void
	*/
	public function __construct(&$db)
	{
		$this->dbobj =& $db;
	}

	/**
	* Strips SQL comments out of an uploaded SQL file.
	*
	* Based on phpBB2's "remove_remarks" function.
	*
	* protected, cannot be accessed directly outside of this class;
	* cannot be modified by child classes.
	*
	* @param  string  SQL content
	* @return string  Uncommented SQL
	*/
	protected function remove_comments($sql)
	{
		$lines = preg_split("#\n#", $sql, -1, PREG_SPLIT_NO_EMPTY);

		$sql = '';

		$linecount = count($lines);

		$output = '';

		for ($i = 0; $i < $linecount; $i++)
		{
			if (($i != ($linecount - 1)) OR (strlen($lines[$i]) > 0))
			{
				if ($lines[$i][0] != '#')
				{
					$output .= $lines[$i] . "\n";
				}
				else
				{
					$output .= "\n";
				}
				// Trading a bit of speed for lower mem. use here.
				$lines[$i] = '';
			}
		}
		return $output;
	}

	/**
	* Splits SQL file into single SQL statements.
	*
	* Based on phpBB2's "split_sql_file" function.
	*
	* protected, cannot be accessed directly outside of this class;
	* cannot be modified by child classes.
	*
	* @param  string  SQL content
	* @param  string  Delimter the SQL commands are separated by.
	* @return string  Split SQL
	*/
	protected function split_sql($sql, $delimiter)
	{
		$tokens = preg_split("#$delimiter#", $sql, -1, PREG_SPLIT_NO_EMPTY);

		$sql = '';

		$output = array();
		$matches = array();

		$token_count = count($tokens);

		for ($i = 0; $i < $token_count; $i++)
		{
			if (($i != ($token_count - 1)) OR (strlen($tokens[$i] > 0)))
			{
				$total_quotes = preg_match_all("/'/", $tokens[$i], $matches);
				$escaped_quotes = preg_match_all("/(?<!\\\\)(\\\\\\\\)*\\\\'/", $tokens[$i], $matches);
				$unescaped_quotes = $total_quotes - $escaped_quotes;

				if (($unescaped_quotes % 2) == 0)
				{
					array_push($output, $tokens[$i]);

					// save memory.
					$tokens[$i] = '';
				}
				else
				{
					$temp = $tokens[$i] . $delimiter;

					// save memory.
					$tokens[$i] = '';

					// Do we have a complete statement yet?
					$complete_stmt = false;

					for ($j = $i + 1; (!$complete_stmt AND ($j < $token_count)); $j++)
					{
						$total_quotes = preg_match_all("/'/", $tokens[$j], $matches);
						$escaped_quotes = preg_match_all("/(?<!\\\\)(\\\\\\\\)*\\\\'/", $tokens[$j], $matches);
						$unescaped_quotes = $total_quotes - $escaped_quotes;

						if (($unescaped_quotes % 2) == 1)
						{
							array_push($output, $temp . $tokens[$j]);

							// save memory.
							$tokens[$j] = '';
							$temp = '';

							$complete_stmt = true;
							$i = $j;
						}
						else
						{
							$temp .= $tokens[$j] . $delimiter;

							// save memory.
							$tokens[$j] = '';
						}
					}
				}
			}
		}
		return $output;
	}

	/**
	* Performs the actual restoration.
	*
	* @param  string   Path to the backup file on the server.
	* @return boolean  true if restore is successful, false if not.
	*/
	public function do_restore($file)
	{
		$this->error = '';

		if (!file_exists($file))
		{
			$this->error = "The SQL backup file doesn't appear to exist at this location:<br /><code>$file</code>\n";
			return false;
		}

		$sql = file_get_contents($file);

		if (empty($sql))
		{
			$this->error = "The SQL backup file appears to be empty? Please double check the file at:<br /><code>$file</code>\n";
			return false;
		}

		$sql = $this->remove_comments($sql);
		$sql = $this->split_sql($sql, ';');

		$count = count($sql);

		for ($i = 0; $i < $count; $i++)
		{
			$tmp_sql = trim($sql[$i]);

			if (!empty($tmp_sql) AND $tmp_sql[0] != '#')
			{
				if (!$this->dbobj->query($tmp_sql))
				{
					$this->error .= $this->dbobj->error;
				}
			}
		}

		if (empty($this->error))
		{
			return true;
		}
		return false;
	}
}

?>