<?php

/**
* @author    Eric Sizemore <admin@domainportfolio.us>
* @package   Domain Name Portfolio
* @link      www.domainportfolio.us
* @version   1.5.2
* @copyright (C) 2006 - 2009 Eric Sizemore
* @license   http://www.domainportfolio.us/docs/license.html GNU Public License
* @file      ./includes/emailer.class.php
*/

if (!defined('IN_DNP'))
{
	die('You\'re not supposed to be here.');
}

/**
* Class to send email. Based on a class by phpBB2.
*/
class emailer
{
	/**
	* The email recipient
	*
	* private, cannot be accessed directly outside of this class.
	*
	* @var string
	*/
	private $to;

	/**
	* The email subject
	*
	* private, cannot be accessed directly outside of this class.
	*
	* @var string
	*/
	private $subject;

	/**
	* The email body
	*
	* private, cannot be accessed directly outside of this class.
	*
	* @var string
	*/
	private $body;

	/**
	* Who the email is from
	*
	* private, cannot be accessed directly outside of this class.
	*
	* @var string
	*/
	private $from;

	/**
	* Host/domain
	*
	* private, cannot be accessed directly outside of this class.
	*
	* @var string
	*/
	private $host;

	/**
	* Extra email headers
	*
	* private, cannot be accessed directly outside of this class.
	*
	* @var string
	*/
	private $extra_headers;

	/**
	* Constructor. Sets who the email is to, who it's from, and subject
	*
	* @param  string  Recipient email
	* @param  string  Who the email is from
	* @param  string  Subject of the email
	* @return void
	*/
	public function __construct($to, $from, $subject)
	{
		$this->host = preg_replace('#^www\.#i', '', dnp_getenv('SERVER_NAME'));
		$this->to = trim($to);
		$this->from = trim($from);
		$this->from = (is_null($from)) ? "noreply@{$this->host}" : $this->from;
		$this->subject = trim($subject);
		$this->extra_headers = '';
	}

	/**
	* Allows us to set extra headers aside from the standard ones in the send() function.
	*
	* @param  string  Extra headers seperated by \n
	* @return void
	*/
	public function extra_headers($headers = '')
	{
		$this->extra_headers .= str_replace("\r\n", "\n", $headers);
	}

	/**
	* Allows us to use templates for the email body
	*
	* @param  array   An array of var => replacement
	* @param  string  Template filename
	* @return void
	*/
	public function use_template($tpl_vars, $tpl_file)
	{
		$tpl_file = (defined('IN_ADMIN') ? '..' : '.') . "/templates/$tpl_file";

		if (!is_array($tpl_vars) OR count($tpl_vars) == 0)
		{
			trigger_error('emailer->use_template - <code>$tpl_vars</code> must be an array, or is empty.', E_USER_ERROR);
		}

		if (!is_file($tpl_file))
		{
			trigger_error("emailer->use_template - '<code>$tpl_file</code>' is not a file or does not exist.", E_USER_ERROR);
		}

		if (!($fp = @fopen($tpl_file, 'r')))
		{
			trigger_error("emailer->use_template - Could not open template file: '<code>$tpl_file</code>'", E_USER_ERROR);
		}

		$this->body = fread($fp, filesize($tpl_file));

		foreach ($tpl_vars AS $var => $content)
		{
			$this->body = str_replace('{' . $var . '}', $content, $this->body);
		}
		fclose($fp);
	}

	/**
	* Wrapper of the mail() function, which also sets standard email headers,
	* plus any extra ones we may add in script via the extra_headers() function.
	*
	* @param  void
	* @return boolean  true if the email is sent, false if not.
	*/
	public function send()
	{
		$headers = "From: {$this->from}\n";
		$headers .= "Reply-To: {$this->from}\n";
		$headers .= "Return-Path: {$this->from}\n";
		$headers .= "Sender: {$this->from}\n";
		$headers .= "Message-ID: <" . dnp_hash(uniqid(time())) . "@{$this->host}>\n";
		$headers .= "MIME-Version: 1.0\n";
		$headers .= "Content-type: text/plain; charset=UTF-8\n";
		$headers .= "Content-transfer-encoding: 8bit\n";
		$headers .= "Date: " . date('r', time()) . "\n";
		$headers .= "X-Priority: 3\n";
		$headers .= "X-MSMail-Priority: Normal\n";
		$headers .= "X-Mailer: Domain Name Portfolio via PHP/" . PHP_VERSION . "\n";
		$headers .= "X-MimeOLE: Produced By Domain Name Portfolio\n";

		if ($this->extra_headers != '')
		{
			$headers .= trim($this->extra_headers) . "\n";
		}

		if (@mail($this->to, $this->subject, $this->body, $headers))
		{
			return true;
		}
		return false;
	}
}

?>