<?php

/**
* @author    Eric Sizemore <admin@domainportfolio.us>
* @package   Domain Name Portfolio
* @link      www.domainportfolio.us
* @version   1.5.2
* @copyright (C) 2006 - 2009 Eric Sizemore
* @license   http://www.domainportfolio.us/docs/license.html GNU Public License
* @file      ./includes/global.php
*/

if (!defined('IN_DNP'))
{
	die('You\'re not supposed to be here.');
}

// ################################################################
// We need at least PHP 5.2
if (!version_compare(PHP_VERSION, '5.2', '>='))
{
	die('Your server is running PHP ' . PHP_VERSION . ', but DNP needs at least PHP 5.2');
}

// ... and filter
if (!function_exists('filter_var'))
{
	die('Your server is not using filter functions. Your DNP installation will not work properly until PHP is configured with filter support.<br /><br />This can be done by adding <code>--enable-filter</code> to the PHP configure command when compiling PHP.');
}

// ... and hash
if (!function_exists('hash'))
{
	die('Your server is not using hash functions. Your DNP installation will not work properly until PHP is configured with hash support.<br /><br />This can be done by adding <code>--enable-hash</code> to the PHP configure command when compiling PHP.');
}

// ... and mbstring
if (!function_exists('mb_strlen'))
{
	die('Your server is not using mbstring functions. Your DNP installation will not work properly until PHP is configured with mbstring support.<br /><br />This can be done by adding <code>--enable-mbstring</code> to the PHP configure command when compiling PHP.');
}

// ################################################################
// We want errors to be displayed.
ini_set('display_errors', 1);

// HTML errors will screw the layout up.
ini_set('html_errors', 0);

// Why have anything else!?
ini_set('arg_separator.output', '&amp;');

// Error reporting
if (version_compare(PHP_VERSION, '5.3', '>='))
{
	error_reporting(E_ALL & ~E_NOTICE & ~E_DEPRECATED);
}
else
{
	error_reporting(E_ALL & ~E_NOTICE);
}

// In PHP 5.3, these are deprecated, so only run if < 5.3
if (version_compare(PHP_VERSION, '5.3', '<'))
{
	set_magic_quotes_runtime(0);

	ini_set('magic_quotes_sybase', 0);
	ini_set('zend.ze1_compatibility_mode', 0);
	ini_set('register_long_arrays', 0);
}

// Session stuff..
ini_set('session.auto_start', 0);
ini_set('session.use_only_cookies', 1);
ini_set('session.use_trans_sid', 0);
ini_set('session.cookie_httponly', 1);

// ################################################################
// Better to be safe than sorry... :)
if (isset($_REQUEST['GLOBALS']) OR isset($_FILES['GLOBALS']))
{
	die('Request tainting attempted.');
}

// Reverse the effects of register_globals if neccessary.
if (ini_get('register_globals') OR strtolower(ini_get('register_globals')) == 'on')
{
	$supers = array('_GET', '_POST', '_COOKIE', '_REQUEST', '_SERVER', '_SESSION', '_ENV', '_FILES');

	if (!isset($_SESSION) OR !is_array($_SESSION))
	{
		$_SESSION = array();
	}

	foreach ($supers AS $arrayname)
	{
		foreach (array_keys($GLOBALS["$arrayname"]) AS $varname)
		{
			if (!in_array($varname, $supers))
			{
				$GLOBALS["$varname"] = NULL;
				unset($GLOBALS["$varname"]);
			}
		}
	}
}

// ################################################################
// Make sure POST's are from the domain DNP is installed on
if (count($_POST) > 0)
{
	$httphost = preg_replace('#^www\.#i', '', $_SERVER['SERVER_NAME']);

	if ($httphost AND $_SERVER['HTTP_REFERER'])
	{
		$refparts = parse_url($_SERVER['HTTP_REFERER']);
		$refhost = $refparts['host'] . ($refparts['port'] ? ':' . $refparts['port'] : '');

		if (strpos($refhost, $httphost) === false)
		{
			die('POST requests are not permitted from "foreign" domains.');
		}
	}
}

// ################################################################
// Include needed files
require_once('config.class.php');
require_once('functions.php');
require_once('database.class.php');
require_once('admin.class.php');

// ################################################################
// Check to see if the install directory was deleted.
if (is_dir((defined('IN_ADMIN') ? '..' : '.') . '/install/') AND !defined('IN_INSTALL'))
{
	die('The <code>./install/</code> directory is still on your server. Either:<br /><ol><li>You\'ve installed the script but have yet to remove the install directory.</li><li>You\'ve not installed yet. If so, <a href="./install/">click here</a> to begin installation.</li><li>You\ve installed the script and you need to upgrade. If so, <a href="./install/upgrade.php">click here</a> to upgrade.</li></ol>If the first case, then please delete the install directory. If you\'ve not installed, install first, then delete.<br />Not deleting it poses a potential security risk.');
}

// ################################################################
$config = new dnp_config();

// Check to see that the database settings in config were changed.
if (
	$config->get('dbuser') == 'username' OR 
	$config->get('dbpass') == 'password' OR 
	$config->get('dbname') == 'database' OR 
	$config->get('dbemail') == 'webmaster@example.com'
)
{
	die('The <code>./includes/config.class.php</code> file still has the default value for one or more of the following:<br /><ul><li>dbuser</li><li>dbpass</li><li>dbname</li><li>dbemail</li></ul>Please open <code>./includes/config.class.php</code> in your favorite text editor and make sure all values are correct.');
}

// ################################################################
switch ($config->get('dbtype'))
{
	case 'mysql':
		$db = new db_mysql($config->get('dbhost'), $config->get('dbuser'), $config->get('dbpass'), $config->get('dbname'));
		break;
	case 'mysqli':
		$db = new db_mysqli($config->get('dbhost'), $config->get('dbuser'), $config->get('dbpass'), $config->get('dbname'));
		break;
	default:
		die('No valid database class found.');
		break;
}

// MySQL Table Prefix
define('TABLE_PREFIX', $config->get('dbprefix'));

// ################################################################
// Get config db options.
$config->get('', true);

// Instantiate admin class
$adm = new admin();

// Current DNP Version, do not change please.
$version = dnp_version();

// Some template stuff
$template = './templates/' . $config->get('template');

/**
* Grab site config options (title, description, etc).
* We only want to do this, though, if we are not in install.
*/
if (!defined('IN_INSTALL'))
{
	$title = $config->get('title');
	$description = $config->get('description');
	$keywords = $config->get('keywords');

	// Start a session
	session_start();

	if (isset($_SESSION['dnp_admin_name'], $_SESSION['dnp_admin_kp']))
	{
		if (($adm->do_login($_SESSION['dnp_admin_name'], $_SESSION['dnp_admin_kp'], true)) AND ($adm->verify_auth()))
		{
			$db->is_admin = true;
		}
	}
}

?>