<?php

/**
* @author    Eric Sizemore <admin@domainportfolio.us>
* @package   Domain Name Portfolio
* @link      www.domainportfolio.us
* @version   1.5.2
* @copyright (C) 2006 - 2009 Eric Sizemore
* @license   http://www.domainportfolio.us/docs/license.html GNU Public License
* @file      ./includes/recaptcha.class.php
*/

if (!defined('IN_DNP'))
{
	die('You\'re not supposed to be here.');
}

/**
* A recaptcha_response is returned from recaptcha::check_answer()
*/
class recaptcha_response
{
	public $is_valid;
	public $error;
	public function __construct() {}
}

/**
* ReCAPTCHA Class
*/
class recaptcha
{
	/**
	* @const API server
	*/
	const RECAPTCHA_API_SERVER = 'http://api.recaptcha.net';
	
	/**
	* @const API server (secure)
	*/
	const RECAPTCHA_API_SECURE_SERVER = 'https://api-secure.recaptcha.net';
	
	/**
	* @const verify server
	*/
	const RECAPTCHA_VERIFY_SERVER = 'api-verify.recaptcha.net';
	
	/**
	* @const DomainPortfolio.us GLOBAL key (public)
	*/
	const RECAPTCHA_PUBLIC_KEY = '6Ldf8AUAAAAAAGSVkI7c-VYKqS9341tTX4x8zcDP';
	
	/**
	* @const DomainPortfolio.us GLOBAL key (private)
	*/
	const RECAPTCHA_PRIVATE_KEY = '6Ldf8AUAAAAAAPWXWyOg9dYTEzvS5-WpcZvNrtT9';

	/**
	* Theme
	*
	* @var string
	*/
	public $theme;

	/**
	* Constructor. Makes sure we have a valid theme set.
	*
	* @param  void
	* @return void
	*/
	public function __construct()
	{
		global $config;

		if (!in_array($config->get('recaptcha'), array('red', 'white', 'blackglass', 'clean')))
		{
			$this->theme = 'red';
		}
		else
		{
			$this->theme = $config->get('recaptcha');
		}
	}

	/**
	* Encodes the given data into a query string format.
	*
	* @param  array   Data to encode.
	* @return string  Encoded data.
	*/
	private function qsencode($data)
	{
		$req = '';

		foreach ($data AS $key => $value)
		{
			$req .= $key . '=' . urlencode(stripslashes($value)) . '&';
		}

		$req = substr($req, 0, strlen($req) - 1);

		return $req;
	}

	/**
	* Submits an HTTP POST to a reCAPTCHA server
	*
	* @param  string   reCAPTCHA server host
	* @param  string   reCAPTCHA server path
	* @param  array    Data to verify response.
	* @param  integer  reCAPTCHA server port
	* @return array    reCAPTCHA response.
	*/
	private function http_post($host, $path, $data, $port = 80)
	{
		$req = $this->qsencode($data);

		$http_request  = "POST $path HTTP/1.0\r\nHost: $host\r\nContent-Type: application/x-www-form-urlencoded;\r\n";
		$http_request .= "Content-Length: " . strlen($req) . "\r\nUser-Agent: reCAPTCHA/PHP\r\n\r\n$req";

		$response = '';

		if (false == ($fs = @fsockopen($host, $port, $errno, $errstr, 10)))
		{
			die('Could not open socket');
		}
		fwrite($fs, $http_request);

		while (!feof($fs))
		{
			$response .= fgets($fs, 1160);
		}
		fclose($fs);

		$response = explode("\r\n\r\n", $response, 2);
		return $response;
	}

	/**
	* Gets the challenge HTML (javascript and non-javascript version).
	* This is called from the browser, and the resulting reCAPTCHA HTML widget
	* is embedded within the HTML form it was called from.
	*
	* @param  string   The error given by reCAPTCHA (optional, default is null)
	* @param  boolean  Should the request be made over ssl? (optional, default is false)
	* @return string   The HTML to be embedded in the user's form.
	*/
	public function get_html($error = NULL, $use_ssl = false)
	{
		if (self::RECAPTCHA_PUBLIC_KEY == '')
		{
			die('To use reCAPTCHA you must get an API key from http://recaptcha.net/api/getkey');
		}

		$server = ($use_ssl) ? self::RECAPTCHA_API_SECURE_SERVER : self::RECAPTCHA_API_SERVER;

		$errorpart = '';

		if ($error)
		{
			$errorpart = "&amp;error=$error";
		}
		return '<script type="text/javascript">var RecaptchaOptions = { theme : \'' . $this->theme . '\' };</script>
		<script type="text/javascript" src="'. $server . '/challenge?k=' . self::RECAPTCHA_PUBLIC_KEY . $errorpart . '"></script>
		<noscript>
	  		<iframe src="'. $server . '/noscript?k=' . self::RECAPTCHA_PUBLIC_KEY . $errorpart . '" height="300" width="500" frameborder="0"></iframe><br />
	  		<textarea name="recaptcha_challenge_field" rows="3" cols="40"></textarea>
	  		<input type="hidden" name="recaptcha_response_field" value="manual_challenge" />
		</noscript>';
	}

	/**
	* Calls an HTTP POST function to verify if the user's guess was correct
	*
	* @param  string  Users IP address
	* @param  string  Challenge string
	* @param  string  User response.
	* @param  array   Any extra parameters.
	* @return object  Resonpse class object.
	*/
	public function check_answer($remoteip, $challenge, $response, $extra_params = array())
	{
		if (self::RECAPTCHA_PRIVATE_KEY == '')
		{
			die('To use reCAPTCHA you must get an API key from http://recaptcha.net/api/getkey');
		}

		if ($remoteip == '')
		{
			die('For security reasons, you must pass the remote ip to reCAPTCHA');
		}

		if (empty($challenge) OR strlen($challenge) == 0 OR empty($response) OR strlen($response) == 0)
		{
			$recaptcha_response = new recaptcha_response();
			$recaptcha_response->is_valid = false;
			$recaptcha_response->error = 'incorrect-captcha-sol';
			return $recaptcha_response;
		}

		$response = $this->http_post(self::RECAPTCHA_VERIFY_SERVER, '/verify', array(
			'privatekey' => self::RECAPTCHA_PRIVATE_KEY,
			'remoteip'   => $remoteip,
			'challenge'  => $challenge,
			'response'   => $response
		) + $extra_params);

		$answers = explode("\n", $response[1]);
		$recaptcha_response = new recaptcha_response();

		if (trim($answers[0]) == 'true')
		{
			$recaptcha_response->is_valid = true;
		}
		else
		{
			$recaptcha_response->is_valid = false;
			$recaptcha_response->error = $answers[1];
		}
		return $recaptcha_response;
	}
}

?>