<?php

/**
* @author    Eric Sizemore <admin@domainportfolio.us>
* @package   Domain Name Portfolio
* @link      www.domainportfolio.us
* @version   1.5.2
* @copyright (C) 2006 - 2009 Eric Sizemore
* @license   http://www.domainportfolio.us/docs/license.html GNU Public License
* @file      ./install/mysql-install.php
*/

// ################################################################################
if (!is_object($db))
{
	exit;
}

// ################################################################################
$schema['CREATE']['query']['admin'] = "
CREATE TABLE " . TABLE_PREFIX . "admin (
	adminid INT UNSIGNED NOT NULL AUTO_INCREMENT,
	username VARCHAR(32) NOT NULL,
	password CHAR(32) NOT NULL,
	PRIMARY KEY (adminid),
	KEY username (username)
)
";
$schema['CREATE']['explain']['admin'] = 'Table <strong>' . TABLE_PREFIX . 'admin</strong> created';

$schema['CREATE']['query']['config'] = "
CREATE TABLE " . TABLE_PREFIX . "config (
	id INT UNSIGNED NOT NULL AUTO_INCREMENT,
	name VARCHAR(25) NOT NULL,
	value VARCHAR(255) NOT NULL,
	PRIMARY KEY (id),
	KEY name (name)
)
";
$schema['CREATE']['explain']['config'] = 'Table <strong>' . TABLE_PREFIX . 'config</strong> created';

$schema['CREATE']['query']['categories'] = "
CREATE TABLE " . TABLE_PREFIX . "categories (
	catid INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
	title VARCHAR(100) NOT NULL,
	description TEXT NOT NULL DEFAULT '',
	keywords TEXT NOT NULL DEFAULT '',
	PRIMARY KEY (catid)
)
";
$schema['CREATE']['explain']['categories'] = 'Table <strong>' . TABLE_PREFIX . 'categories</strong> created';

$schema['CREATE']['query']['domains'] = "
CREATE TABLE " . TABLE_PREFIX . "domains (
	domainid INT UNSIGNED NOT NULL AUTO_INCREMENT,
	domain VARCHAR(100) NOT NULL,
	catid INT UNSIGNED NOT NULL,
	description TEXT NOT NULL DEFAULT '',
	keywords TEXT NOT NULL DEFAULT '',
	registrar VARCHAR(100) NOT NULL,
	expiry INT(11) UNSIGNED NOT NULL DEFAULT '0',
	price DECIMAL(10,2) NOT NULL DEFAULT '0.00',
	status ENUM('For Sale', 'Not For Sale', 'Make Offer', 'Sold') NOT NULL,
	added INT(11) UNSIGNED NOT NULL DEFAULT '0',
	issite TINYINT(1) UNSIGNED NOT NULL DEFAULT '0',
	hidden TINYINT(1) UNSIGNED NOT NULL DEFAULT '0',
	PRIMARY KEY (domainid),
	KEY catid (catid),
	KEY hidden (hidden)
)
";
$schema['CREATE']['explain']['domains'] = 'Table <strong>' . TABLE_PREFIX . 'domains</strong> created';

// ################################################################################

$schema['INSERT']['query']['config'] = "
	INSERT INTO " . TABLE_PREFIX . "config 
		(name, value)
	VALUES 
		('title', '" . $db->prepare($title) . "'),
		('description', '" . $db->prepare($description) . "'),
		('keywords', '" . $db->prepare($keywords) . "'),
		('maxperpage', $perpage),
		('contactemail', '" . $db->prepare($email) . "'),
		('currency', '" . $db->prepare($currency) . "')
";
$schema['INSERT']['explain']['config'] = 'Data for <strong>config</strong> entered';

$schema['INSERT']['query']['admin'] = "
	INSERT INTO " . TABLE_PREFIX . "admin 
		(username, password)
	VALUES 
		('" . $db->prepare($username) . "', '" . dnp_hash($password) . "')
";
$schema['INSERT']['explain']['admin'] = 'Data for <strong>admin</strong> entered';

?>