<?php

/**
* @author    Eric Sizemore <admin@domainportfolio.us>
* @package   Domain Name Portfolio
* @link      www.domainportfolio.us
* @version   1.5.2
* @copyright (C) 2006 - 2009 Eric Sizemore
* @license   http://www.domainportfolio.us/docs/license.html GNU Public License
* @file      ./install/upgrade.php
*/

// ########################################################################
ignore_user_abort(true);

define('IN_DNP', true);
define('IN_INSTALL', true);

// ########################################################################
function do_queries()
{
	global $db, $query, $explain;

	if (is_array($query))
	{
		echo '<ul>';

		foreach ($query AS $key => $val)
		{
			if (is_array($val))
			{
				$val = array_pop($val);
			}

			echo "<li>$explain[$key]</li>\n<!-- " . htmlspecialchars($val) . " -->\n\n";
			flush();

			$db->query($val);
		}

		echo '</ul>';
	}
	unset($GLOBALS['query'], $GLOBALS['explain']);
}

// ################################################################
require_once('../includes/global.php');

$_REQUEST['step'] = (empty($_REQUEST['step'])) ? 1 : intval($_REQUEST['step']);

// We're in upgrade, we want to show db errors
$db->is_admin = true;

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
<title>Domain Name Portfolio Upgrade - Step <?php echo $_REQUEST['step']; ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<link rel="stylesheet" href="./style/install.css" />
</head>

<body style="margin: 0px">

<div id="body">
	<table cellpadding="4" cellspacing="0" border="0" width="100%" align="center" class="table" style="border: outset 1px;">
	<tr>
		<td width="180" style="padding-left: 20px;"><img src="./style/logo.png" alt="Domain Name Portfolio" border="0" /></td>
		<td style="padding-left: 30px; font-weight: bold;">
			Version <?php echo $version; ?> Upgrade<br />
			Step <?php echo $_REQUEST['step']; ?>
		</td>
	</tr>
	</table>
	<form action="upgrade.php" method="post">
<?php

// ########################################################################
if ($_REQUEST['step'] == 1)
{
	echo '
	<blockquote>
		<p style="font-weight: bold;">Welcome to Domain Name Portfolio version ' . $version . '</p>
		<p>You are about to perform an upgrade.</p>
		<p>Clicking the <code>Next Step</code> button will begin the upgrade process.</p>
	</blockquote>
';
}

if ($_REQUEST['step'] == 2)
{
?>
	<table>
	<tbody>
	<tr>
		<td style="font-weight: bold;">Please choose the version you are upgrading from:</td>
		<td style="text-align: left;">
			<select name="from">
				<option label="0.9.x" value="0.9">0.9.x</option>
				<option label="1.0.x" value="1.0">1.0.x</option>
			</select>
		</td>
	</tr>
	<tr>
		<td style="font-weight: bold;" colspan="2">
			By upgrading, you are agreeing to our license, the <a href="license.txt" target="_blank">GNU GPL v3</a>
		</td>
	</tr>
	</tbody>
	</table>
<?php
}

if ($_REQUEST['step'] == 3)
{
	$from = sanitize($_POST['from']);

	$errors = array();

	// ################################################################
	// Check to see if the required fields are empty
	if (empty($from))
	{
		array_push($errors, 'You must choose a version to upgrade from');
	}

	if (!in_array($from, array('0.9', '1.0')))
	{
		array_push($errors, 'Invalid version to upgrade from');
	}

	if (count($errors))
	{
		echo "The following errors occurred:<br />\n<ul>\n";

		foreach ($errors AS $error)
		{
			echo "<li>$error</li>\n";
		}

		echo "</ul>\n";
		unset($errors);

		$_REQUEST['step'] = 2;
	}
	else
	{
		if ($from == '1.0')
		{
			echo "<p>There are no database upgrades needed for version $version, if you are upgrading from 1.0.x. However, the template system in version $version has been completely redone. Templates now use more of a WordPress style syntax. If you've customized the templates in previous versions, you'll have to reapply them on the new templates.</p>";
		}
		else
		{
			require_once('mysql-upgrade.php');
	
			$query =& $schema['ALTER']['query'];
			$explain =& $schema['ALTER']['explain'];
			do_queries();

			if (isset($schema['INSERT']))
			{
				$query =& $schema['INSERT']['query'];
				$explain =& $schema['INSERT']['explain'];
				do_queries();
			}
			echo "<p>The template system in version $version has been completely redone. Templates now use more of a WordPress style syntax. If you've customized the templates in previous versions, you'll have to reapply them on the new templates.</p>";
		}
	}
}

if ($_REQUEST['step'] == 4)
{
	echo '
	<blockquote>
		<p style="font-weight: bold;">Installation Complete!</p>
		<p>Thank you for upgrading Domain Name Portfolio.</p>
		<p>Please delete the <code>./install/</code> directory before continuing.</p>
	</blockquote>
';
}

?>
	<input type="hidden" name="step" value="<?php echo $_REQUEST['step'] + 1; ?>" />
	<table cellpadding="4" cellspacing="0" border="0" width="100%" align="center" class="table" style="padding: 4px; border: outset 1px;">
	<tr align="center">
<?php

if ($_REQUEST['step'] < 4)
{
?>
		<td style="font-weight: bold;">Click the button on the right to proceed.</td>
		<td><input type="submit" class="button" value="Next Step" title="Next Step" /></td>
<?php
}
else
{
?>
		<td colspan="2">&nbsp;</td>
<?php
}

?>
	</tr>
	</table>
	</form>
</div>
<p align="center">
	<a href="http://www.domainportfolio.us/" target="_blank" class="copyright">Copyright &copy; 2006 - <?php echo date('Y'); ?> Eric Sizemore (SecondVersion)</a>
</p>

</body>
</html>